/*
 * SPDX-License-Identifier: ODbL-1.0
 * SPDX-FileCopyrightText: OpenStreetMap contributors
 *
 * Autogenerated using QGIS - do not edit!
 */

#include "isocodes_p.h"
#include "mapentry_p.h"
#include "timezone_names_p.h"

static constexpr const MapEntry<uint16_t> country_timezone_map[] = {
    {IsoCodes::alpha2CodeToKey("AD"), Tz::Europe_Andorra},
    {IsoCodes::alpha2CodeToKey("AE"), Tz::Asia_Dubai},
    {IsoCodes::alpha2CodeToKey("AF"), Tz::Asia_Kabul},
    {IsoCodes::alpha2CodeToKey("AG"), Tz::America_Antigua},
    {IsoCodes::alpha2CodeToKey("AI"), Tz::America_Anguilla},
    {IsoCodes::alpha2CodeToKey("AL"), Tz::Europe_Tirane},
    {IsoCodes::alpha2CodeToKey("AM"), Tz::Asia_Yerevan},
    {IsoCodes::alpha2CodeToKey("AO"), Tz::Africa_Luanda},
    {IsoCodes::alpha2CodeToKey("AR"), Tz::America_Argentina_Buenos_Aires},
    {IsoCodes::alpha2CodeToKey("AS"), Tz::Pacific_Pago_Pago},
    {IsoCodes::alpha2CodeToKey("AT"), Tz::Europe_Vienna},
    {IsoCodes::alpha2CodeToKey("AW"), Tz::America_Aruba},
    {IsoCodes::alpha2CodeToKey("AX"), Tz::Europe_Helsinki},
    {IsoCodes::alpha2CodeToKey("AZ"), Tz::Asia_Baku},
    {IsoCodes::alpha2CodeToKey("BA"), Tz::Europe_Sarajevo},
    {IsoCodes::alpha2CodeToKey("BB"), Tz::America_Barbados},
    {IsoCodes::alpha2CodeToKey("BD"), Tz::Asia_Dhaka},
    {IsoCodes::alpha2CodeToKey("BE"), Tz::Europe_Brussels},
    {IsoCodes::alpha2CodeToKey("BF"), Tz::Africa_Ouagadougou},
    {IsoCodes::alpha2CodeToKey("BG"), Tz::Europe_Sofia},
    {IsoCodes::alpha2CodeToKey("BH"), Tz::Asia_Bahrain},
    {IsoCodes::alpha2CodeToKey("BI"), Tz::Africa_Bujumbura},
    {IsoCodes::alpha2CodeToKey("BJ"), Tz::Africa_Porto_Novo},
    {IsoCodes::alpha2CodeToKey("BL"), Tz::America_St_Barthelemy},
    {IsoCodes::alpha2CodeToKey("BM"), Tz::Atlantic_Bermuda},
    {IsoCodes::alpha2CodeToKey("BN"), Tz::Asia_Brunei},
    {IsoCodes::alpha2CodeToKey("BO"), Tz::America_La_Paz},
    {IsoCodes::alpha2CodeToKey("BQ"), Tz::America_Kralendijk},
    {IsoCodes::alpha2CodeToKey("BS"), Tz::America_Nassau},
    {IsoCodes::alpha2CodeToKey("BT"), Tz::Asia_Thimphu},
    {IsoCodes::alpha2CodeToKey("BW"), Tz::Africa_Gaborone},
    {IsoCodes::alpha2CodeToKey("BY"), Tz::Europe_Minsk},
    {IsoCodes::alpha2CodeToKey("BZ"), Tz::America_Belize},
    {IsoCodes::alpha2CodeToKey("CC"), Tz::Indian_Cocos},
    {IsoCodes::alpha2CodeToKey("CF"), Tz::Africa_Bangui},
    {IsoCodes::alpha2CodeToKey("CG"), Tz::Africa_Brazzaville},
    {IsoCodes::alpha2CodeToKey("CH"), Tz::Europe_Zurich},
    {IsoCodes::alpha2CodeToKey("CI"), Tz::Africa_Abidjan},
    {IsoCodes::alpha2CodeToKey("CK"), Tz::Pacific_Rarotonga},
    {IsoCodes::alpha2CodeToKey("CM"), Tz::Africa_Douala},
    {IsoCodes::alpha2CodeToKey("CO"), Tz::America_Bogota},
    {IsoCodes::alpha2CodeToKey("CR"), Tz::America_Costa_Rica},
    {IsoCodes::alpha2CodeToKey("CU"), Tz::America_Havana},
    {IsoCodes::alpha2CodeToKey("CV"), Tz::Atlantic_Cape_Verde},
    {IsoCodes::alpha2CodeToKey("CW"), Tz::America_Curacao},
    {IsoCodes::alpha2CodeToKey("CX"), Tz::Indian_Christmas},
    {IsoCodes::alpha2CodeToKey("CY"), Tz::Asia_Nicosia},
    {IsoCodes::alpha2CodeToKey("CZ"), Tz::Europe_Prague},
    {IsoCodes::alpha2CodeToKey("DE"), Tz::Europe_Berlin},
    {IsoCodes::alpha2CodeToKey("DJ"), Tz::Africa_Djibouti},
    {IsoCodes::alpha2CodeToKey("DK"), Tz::Europe_Copenhagen},
    {IsoCodes::alpha2CodeToKey("DM"), Tz::America_Dominica},
    {IsoCodes::alpha2CodeToKey("DO"), Tz::America_Santo_Domingo},
    {IsoCodes::alpha2CodeToKey("DZ"), Tz::Africa_Algiers},
    {IsoCodes::alpha2CodeToKey("EE"), Tz::Europe_Tallinn},
    {IsoCodes::alpha2CodeToKey("EG"), Tz::Africa_Cairo},
    {IsoCodes::alpha2CodeToKey("EH"), Tz::Africa_El_Aaiun},
    {IsoCodes::alpha2CodeToKey("ER"), Tz::Africa_Asmara},
    {IsoCodes::alpha2CodeToKey("ET"), Tz::Africa_Addis_Ababa},
    {IsoCodes::alpha2CodeToKey("FI"), Tz::Europe_Helsinki},
    {IsoCodes::alpha2CodeToKey("FJ"), Tz::Pacific_Fiji},
    {IsoCodes::alpha2CodeToKey("FK"), Tz::Atlantic_Stanley},
    {IsoCodes::alpha2CodeToKey("FO"), Tz::Atlantic_Faroe},
    {IsoCodes::alpha2CodeToKey("GA"), Tz::Africa_Libreville},
    {IsoCodes::alpha2CodeToKey("GB"), Tz::Europe_London},
    {IsoCodes::alpha2CodeToKey("GD"), Tz::America_Grenada},
    {IsoCodes::alpha2CodeToKey("GF"), Tz::America_Cayenne},
    {IsoCodes::alpha2CodeToKey("GG"), Tz::Europe_Guernsey},
    {IsoCodes::alpha2CodeToKey("GH"), Tz::Africa_Accra},
    {IsoCodes::alpha2CodeToKey("GI"), Tz::Europe_Gibraltar},
    {IsoCodes::alpha2CodeToKey("GM"), Tz::Africa_Banjul},
    {IsoCodes::alpha2CodeToKey("GN"), Tz::Africa_Conakry},
    {IsoCodes::alpha2CodeToKey("GP"), Tz::America_Guadeloupe},
    {IsoCodes::alpha2CodeToKey("GQ"), Tz::Africa_Malabo},
    {IsoCodes::alpha2CodeToKey("GR"), Tz::Europe_Athens},
    {IsoCodes::alpha2CodeToKey("GS"), Tz::Atlantic_South_Georgia},
    {IsoCodes::alpha2CodeToKey("GT"), Tz::America_Guatemala},
    {IsoCodes::alpha2CodeToKey("GU"), Tz::Pacific_Guam},
    {IsoCodes::alpha2CodeToKey("GW"), Tz::Africa_Bissau},
    {IsoCodes::alpha2CodeToKey("GY"), Tz::America_Guyana},
    {IsoCodes::alpha2CodeToKey("HK"), Tz::Asia_Hong_Kong},
    {IsoCodes::alpha2CodeToKey("HN"), Tz::America_Tegucigalpa},
    {IsoCodes::alpha2CodeToKey("HR"), Tz::Europe_Zagreb},
    {IsoCodes::alpha2CodeToKey("HT"), Tz::America_Port_au_Prince},
    {IsoCodes::alpha2CodeToKey("HU"), Tz::Europe_Budapest},
    {IsoCodes::alpha2CodeToKey("IE"), Tz::Europe_Dublin},
    {IsoCodes::alpha2CodeToKey("IL"), Tz::Asia_Jerusalem},
    {IsoCodes::alpha2CodeToKey("IM"), Tz::Europe_Isle_of_Man},
    {IsoCodes::alpha2CodeToKey("IN"), Tz::Asia_Kolkata},
    {IsoCodes::alpha2CodeToKey("IO"), Tz::Indian_Chagos},
    {IsoCodes::alpha2CodeToKey("IQ"), Tz::Asia_Baghdad},
    {IsoCodes::alpha2CodeToKey("IR"), Tz::Asia_Tehran},
    {IsoCodes::alpha2CodeToKey("IS"), Tz::Atlantic_Reykjavik},
    {IsoCodes::alpha2CodeToKey("IT"), Tz::Europe_Rome},
    {IsoCodes::alpha2CodeToKey("JE"), Tz::Europe_Jersey},
    {IsoCodes::alpha2CodeToKey("JM"), Tz::America_Jamaica},
    {IsoCodes::alpha2CodeToKey("JO"), Tz::Asia_Amman},
    {IsoCodes::alpha2CodeToKey("JP"), Tz::Asia_Tokyo},
    {IsoCodes::alpha2CodeToKey("KE"), Tz::Africa_Nairobi},
    {IsoCodes::alpha2CodeToKey("KG"), Tz::Asia_Bishkek},
    {IsoCodes::alpha2CodeToKey("KH"), Tz::Asia_Phnom_Penh},
    {IsoCodes::alpha2CodeToKey("KM"), Tz::Indian_Comoro},
    {IsoCodes::alpha2CodeToKey("KN"), Tz::America_St_Kitts},
    {IsoCodes::alpha2CodeToKey("KP"), Tz::Asia_Pyongyang},
    {IsoCodes::alpha2CodeToKey("KR"), Tz::Asia_Seoul},
    {IsoCodes::alpha2CodeToKey("KW"), Tz::Asia_Kuwait},
    {IsoCodes::alpha2CodeToKey("KY"), Tz::America_Cayman},
    {IsoCodes::alpha2CodeToKey("LA"), Tz::Asia_Vientiane},
    {IsoCodes::alpha2CodeToKey("LB"), Tz::Asia_Beirut},
    {IsoCodes::alpha2CodeToKey("LC"), Tz::America_St_Lucia},
    {IsoCodes::alpha2CodeToKey("LI"), Tz::Europe_Vaduz},
    {IsoCodes::alpha2CodeToKey("LK"), Tz::Asia_Colombo},
    {IsoCodes::alpha2CodeToKey("LR"), Tz::Africa_Monrovia},
    {IsoCodes::alpha2CodeToKey("LS"), Tz::Africa_Maseru},
    {IsoCodes::alpha2CodeToKey("LT"), Tz::Europe_Vilnius},
    {IsoCodes::alpha2CodeToKey("LU"), Tz::Europe_Luxembourg},
    {IsoCodes::alpha2CodeToKey("LV"), Tz::Europe_Riga},
    {IsoCodes::alpha2CodeToKey("LY"), Tz::Africa_Tripoli},
    {IsoCodes::alpha2CodeToKey("MC"), Tz::Europe_Monaco},
    {IsoCodes::alpha2CodeToKey("MD"), Tz::Europe_Chisinau},
    {IsoCodes::alpha2CodeToKey("ME"), Tz::Europe_Podgorica},
    {IsoCodes::alpha2CodeToKey("MF"), Tz::America_Marigot},
    {IsoCodes::alpha2CodeToKey("MG"), Tz::Indian_Antananarivo},
    {IsoCodes::alpha2CodeToKey("MK"), Tz::Europe_Skopje},
    {IsoCodes::alpha2CodeToKey("ML"), Tz::Africa_Bamako},
    {IsoCodes::alpha2CodeToKey("MM"), Tz::Asia_Yangon},
    {IsoCodes::alpha2CodeToKey("MO"), Tz::Asia_Macau},
    {IsoCodes::alpha2CodeToKey("MP"), Tz::Pacific_Saipan},
    {IsoCodes::alpha2CodeToKey("MQ"), Tz::America_Martinique},
    {IsoCodes::alpha2CodeToKey("MR"), Tz::Africa_Nouakchott},
    {IsoCodes::alpha2CodeToKey("MS"), Tz::America_Montserrat},
    {IsoCodes::alpha2CodeToKey("MT"), Tz::Europe_Malta},
    {IsoCodes::alpha2CodeToKey("MU"), Tz::Indian_Mauritius},
    {IsoCodes::alpha2CodeToKey("MV"), Tz::Indian_Maldives},
    {IsoCodes::alpha2CodeToKey("MW"), Tz::Africa_Blantyre},
    {IsoCodes::alpha2CodeToKey("MY"), Tz::Asia_Kuala_Lumpur},
    {IsoCodes::alpha2CodeToKey("MZ"), Tz::Africa_Maputo},
    {IsoCodes::alpha2CodeToKey("NA"), Tz::Africa_Windhoek},
    {IsoCodes::alpha2CodeToKey("NC"), Tz::Pacific_Noumea},
    {IsoCodes::alpha2CodeToKey("NE"), Tz::Africa_Niamey},
    {IsoCodes::alpha2CodeToKey("NF"), Tz::Pacific_Norfolk},
    {IsoCodes::alpha2CodeToKey("NG"), Tz::Africa_Lagos},
    {IsoCodes::alpha2CodeToKey("NI"), Tz::America_Managua},
    {IsoCodes::alpha2CodeToKey("NO"), Tz::Europe_Oslo},
    {IsoCodes::alpha2CodeToKey("NP"), Tz::Asia_Kathmandu},
    {IsoCodes::alpha2CodeToKey("NR"), Tz::Pacific_Nauru},
    {IsoCodes::alpha2CodeToKey("NU"), Tz::Pacific_Niue},
    {IsoCodes::alpha2CodeToKey("OM"), Tz::Asia_Muscat},
    {IsoCodes::alpha2CodeToKey("PA"), Tz::America_Panama},
    {IsoCodes::alpha2CodeToKey("PE"), Tz::America_Lima},
    {IsoCodes::alpha2CodeToKey("PH"), Tz::Asia_Manila},
    {IsoCodes::alpha2CodeToKey("PK"), Tz::Asia_Karachi},
    {IsoCodes::alpha2CodeToKey("PL"), Tz::Europe_Warsaw},
    {IsoCodes::alpha2CodeToKey("PM"), Tz::America_Miquelon},
    {IsoCodes::alpha2CodeToKey("PN"), Tz::Pacific_Pitcairn},
    {IsoCodes::alpha2CodeToKey("PR"), Tz::America_Puerto_Rico},
    {IsoCodes::alpha2CodeToKey("PW"), Tz::Pacific_Palau},
    {IsoCodes::alpha2CodeToKey("PY"), Tz::America_Asuncion},
    {IsoCodes::alpha2CodeToKey("QA"), Tz::Asia_Qatar},
    {IsoCodes::alpha2CodeToKey("RE"), Tz::Indian_Reunion},
    {IsoCodes::alpha2CodeToKey("RO"), Tz::Europe_Bucharest},
    {IsoCodes::alpha2CodeToKey("RS"), Tz::Europe_Belgrade},
    {IsoCodes::alpha2CodeToKey("RW"), Tz::Africa_Kigali},
    {IsoCodes::alpha2CodeToKey("SA"), Tz::Asia_Riyadh},
    {IsoCodes::alpha2CodeToKey("SB"), Tz::Pacific_Guadalcanal},
    {IsoCodes::alpha2CodeToKey("SC"), Tz::Indian_Mahe},
    {IsoCodes::alpha2CodeToKey("SE"), Tz::Europe_Stockholm},
    {IsoCodes::alpha2CodeToKey("SG"), Tz::Asia_Singapore},
    {IsoCodes::alpha2CodeToKey("SH"), Tz::Atlantic_St_Helena},
    {IsoCodes::alpha2CodeToKey("SI"), Tz::Europe_Ljubljana},
    {IsoCodes::alpha2CodeToKey("SJ"), Tz::Europe_Oslo},
    {IsoCodes::alpha2CodeToKey("SK"), Tz::Europe_Bratislava},
    {IsoCodes::alpha2CodeToKey("SL"), Tz::Africa_Freetown},
    {IsoCodes::alpha2CodeToKey("SM"), Tz::Europe_San_Marino},
    {IsoCodes::alpha2CodeToKey("SN"), Tz::Africa_Dakar},
    {IsoCodes::alpha2CodeToKey("SO"), Tz::Africa_Mogadishu},
    {IsoCodes::alpha2CodeToKey("SR"), Tz::America_Paramaribo},
    {IsoCodes::alpha2CodeToKey("ST"), Tz::Africa_Sao_Tome},
    {IsoCodes::alpha2CodeToKey("SV"), Tz::America_El_Salvador},
    {IsoCodes::alpha2CodeToKey("SX"), Tz::America_Lower_Princes},
    {IsoCodes::alpha2CodeToKey("SY"), Tz::Asia_Damascus},
    {IsoCodes::alpha2CodeToKey("SZ"), Tz::Africa_Mbabane},
    {IsoCodes::alpha2CodeToKey("TC"), Tz::America_Grand_Turk},
    {IsoCodes::alpha2CodeToKey("TD"), Tz::Africa_Ndjamena},
    {IsoCodes::alpha2CodeToKey("TF"), Tz::Indian_Kerguelen},
    {IsoCodes::alpha2CodeToKey("TG"), Tz::Africa_Lome},
    {IsoCodes::alpha2CodeToKey("TH"), Tz::Asia_Bangkok},
    {IsoCodes::alpha2CodeToKey("TJ"), Tz::Asia_Dushanbe},
    {IsoCodes::alpha2CodeToKey("TK"), Tz::Pacific_Fakaofo},
    {IsoCodes::alpha2CodeToKey("TL"), Tz::Asia_Dili},
    {IsoCodes::alpha2CodeToKey("TM"), Tz::Asia_Ashgabat},
    {IsoCodes::alpha2CodeToKey("TN"), Tz::Africa_Tunis},
    {IsoCodes::alpha2CodeToKey("TO"), Tz::Pacific_Tongatapu},
    {IsoCodes::alpha2CodeToKey("TR"), Tz::Europe_Istanbul},
    {IsoCodes::alpha2CodeToKey("TT"), Tz::America_Port_of_Spain},
    {IsoCodes::alpha2CodeToKey("TV"), Tz::Pacific_Funafuti},
    {IsoCodes::alpha2CodeToKey("TW"), Tz::Asia_Taipei},
    {IsoCodes::alpha2CodeToKey("TZ"), Tz::Africa_Dar_es_Salaam},
    {IsoCodes::alpha2CodeToKey("UG"), Tz::Africa_Kampala},
    {IsoCodes::alpha2CodeToKey("UY"), Tz::America_Montevideo},
    {IsoCodes::alpha2CodeToKey("VA"), Tz::Europe_Vatican},
    {IsoCodes::alpha2CodeToKey("VC"), Tz::America_St_Vincent},
    {IsoCodes::alpha2CodeToKey("VE"), Tz::America_Caracas},
    {IsoCodes::alpha2CodeToKey("VG"), Tz::America_Tortola},
    {IsoCodes::alpha2CodeToKey("VI"), Tz::America_St_Thomas},
    {IsoCodes::alpha2CodeToKey("VU"), Tz::Pacific_Efate},
    {IsoCodes::alpha2CodeToKey("WF"), Tz::Pacific_Wallis},
    {IsoCodes::alpha2CodeToKey("WS"), Tz::Pacific_Apia},
    {IsoCodes::alpha2CodeToKey("XK"), Tz::Europe_Belgrade},
    {IsoCodes::alpha2CodeToKey("YE"), Tz::Asia_Aden},
    {IsoCodes::alpha2CodeToKey("YT"), Tz::Indian_Mayotte},
    {IsoCodes::alpha2CodeToKey("ZA"), Tz::Africa_Johannesburg},
    {IsoCodes::alpha2CodeToKey("ZM"), Tz::Africa_Lusaka},
    {IsoCodes::alpha2CodeToKey("ZW"), Tz::Africa_Harare},
};
