/*
 * SPDX-License-Identifier: CC0-1.0
 * SPDX-FileCopyrightText: none
 *
 * Autogenerated spatial index generated using QGIS.
 */

#include <cstdint>

constexpr const float XStart = -180;
constexpr const float XRange = 360;
constexpr const float YStart = -60;
constexpr const float YRange = 140;
constexpr const uint8_t ZDepth = 11;
