/*
 * SPDX-License-Identifier: ODbL-1.0
 * SPDX-FileCopyrightText: OpenStreetMap contributors
 *
 * Autogenerated using QGIS - do not edit!
 */

#ifndef TIMEZONE_NAMES_P_H
#define TIMEZONE_NAMES_P_H

#include <cstdint>

enum Tz : uint16_t {
    Africa_Abidjan = 0,
    Africa_Accra = 15,
    Africa_Addis_Ababa = 28,
    Africa_Algiers = 47,
    Africa_Asmara = 62,
    Africa_Bamako = 76,
    Africa_Bangui = 90,
    Africa_Banjul = 104,
    Africa_Bissau = 118,
    Africa_Blantyre = 132,
    Africa_Brazzaville = 148,
    Africa_Bujumbura = 167,
    Africa_Cairo = 184,
    Africa_Casablanca = 197,
    Africa_Ceuta = 215,
    Africa_Conakry = 228,
    Africa_Dakar = 243,
    Africa_Dar_es_Salaam = 256,
    Africa_Djibouti = 277,
    Africa_Douala = 293,
    Africa_El_Aaiun = 307,
    Africa_Freetown = 323,
    Africa_Gaborone = 339,
    Africa_Harare = 355,
    Africa_Johannesburg = 369,
    Africa_Juba = 389,
    Africa_Kampala = 401,
    Africa_Khartoum = 416,
    Africa_Kigali = 432,
    Africa_Kinshasa = 446,
    Africa_Lagos = 462,
    Africa_Libreville = 475,
    Africa_Lome = 493,
    Africa_Luanda = 505,
    Africa_Lubumbashi = 519,
    Africa_Lusaka = 537,
    Africa_Malabo = 551,
    Africa_Maputo = 565,
    Africa_Maseru = 579,
    Africa_Mbabane = 593,
    Africa_Mogadishu = 608,
    Africa_Monrovia = 625,
    Africa_Nairobi = 641,
    Africa_Ndjamena = 656,
    Africa_Niamey = 672,
    Africa_Nouakchott = 686,
    Africa_Ouagadougou = 704,
    Africa_Porto_Novo = 723,
    Africa_Sao_Tome = 741,
    Africa_Tripoli = 757,
    Africa_Tunis = 772,
    Africa_Windhoek = 785,
    America_Adak = 801,
    America_Anchorage = 814,
    America_Anguilla = 832,
    America_Antigua = 849,
    America_Araguaina = 865,
    America_Argentina_Buenos_Aires = 883,
    America_Argentina_Catamarca = 914,
    America_Argentina_Cordoba = 942,
    America_Argentina_Jujuy = 968,
    America_Argentina_La_Rioja = 992,
    America_Argentina_Mendoza = 1019,
    America_Argentina_Rio_Gallegos = 1045,
    America_Argentina_Salta = 1076,
    America_Argentina_San_Juan = 1100,
    America_Argentina_San_Luis = 1127,
    America_Argentina_Tucuman = 1154,
    America_Argentina_Ushuaia = 1180,
    America_Aruba = 1206,
    America_Asuncion = 1220,
    America_Atikokan = 1237,
    America_Bahia = 1254,
    America_Bahia_Banderas = 1268,
    America_Barbados = 1291,
    America_Belem = 1308,
    America_Belize = 1322,
    America_Blanc_Sablon = 1337,
    America_Boa_Vista = 1358,
    America_Bogota = 1376,
    America_Boise = 1391,
    America_Cambridge_Bay = 1405,
    America_Campo_Grande = 1427,
    America_Cancun = 1448,
    America_Caracas = 1463,
    America_Cayenne = 1479,
    America_Cayman = 1495,
    America_Chicago = 1510,
    America_Chihuahua = 1526,
    America_Costa_Rica = 1544,
    America_Creston = 1563,
    America_Cuiaba = 1579,
    America_Curacao = 1594,
    America_Danmarkshavn = 1610,
    America_Dawson = 1631,
    America_Dawson_Creek = 1646,
    America_Denver = 1667,
    America_Detroit = 1682,
    America_Dominica = 1698,
    America_Edmonton = 1715,
    America_Eirunepe = 1732,
    America_El_Salvador = 1749,
    America_Fort_Nelson = 1769,
    America_Fortaleza = 1789,
    America_Glace_Bay = 1807,
    America_Goose_Bay = 1825,
    America_Grand_Turk = 1843,
    America_Grenada = 1862,
    America_Guadeloupe = 1878,
    America_Guatemala = 1897,
    America_Guayaquil = 1915,
    America_Guyana = 1933,
    America_Halifax = 1948,
    America_Havana = 1964,
    America_Hermosillo = 1979,
    America_Indiana_Indianapolis = 1998,
    America_Indiana_Knox = 2027,
    America_Indiana_Marengo = 2048,
    America_Indiana_Petersburg = 2072,
    America_Indiana_Tell_City = 2099,
    America_Indiana_Vevay = 2125,
    America_Indiana_Vincennes = 2147,
    America_Indiana_Winamac = 2173,
    America_Inuvik = 2197,
    America_Iqaluit = 2212,
    America_Jamaica = 2228,
    America_Juneau = 2244,
    America_Kentucky_Louisville = 2259,
    America_Kentucky_Monticello = 2287,
    America_Kralendijk = 2315,
    America_La_Paz = 2334,
    America_Lima = 2349,
    America_Los_Angeles = 2362,
    America_Lower_Princes = 2382,
    America_Maceio = 2404,
    America_Managua = 2419,
    America_Manaus = 2435,
    America_Marigot = 2450,
    America_Martinique = 2466,
    America_Matamoros = 2485,
    America_Mazatlan = 2503,
    America_Menominee = 2520,
    America_Merida = 2538,
    America_Metlakatla = 2553,
    America_Mexico_City = 2572,
    America_Miquelon = 2592,
    America_Moncton = 2609,
    America_Monterrey = 2625,
    America_Montevideo = 2643,
    America_Montserrat = 2662,
    America_Nassau = 2681,
    America_New_York = 2696,
    America_Nipigon = 2713,
    America_Nome = 2729,
    America_Noronha = 2742,
    America_North_Dakota_Beulah = 2758,
    America_North_Dakota_Center = 2786,
    America_North_Dakota_New_Salem = 2814,
    America_Nuuk = 2845,
    America_Ojinaga = 2858,
    America_Panama = 2874,
    America_Pangnirtung = 2889,
    America_Paramaribo = 2909,
    America_Phoenix = 2928,
    America_Port_au_Prince = 2944,
    America_Port_of_Spain = 2967,
    America_Porto_Velho = 2989,
    America_Puerto_Rico = 3009,
    America_Punta_Arenas = 3029,
    America_Rainy_River = 3050,
    America_Rankin_Inlet = 3070,
    America_Recife = 3091,
    America_Regina = 3106,
    America_Resolute = 3121,
    America_Rio_Branco = 3138,
    America_Santarem = 3157,
    America_Santiago = 3174,
    America_Santo_Domingo = 3191,
    America_Sao_Paulo = 3213,
    America_Scoresbysund = 3231,
    America_Sitka = 3252,
    America_St_Barthelemy = 3266,
    America_St_Johns = 3288,
    America_St_Kitts = 3305,
    America_St_Lucia = 3322,
    America_St_Thomas = 3339,
    America_St_Vincent = 3357,
    America_Swift_Current = 3376,
    America_Tegucigalpa = 3398,
    America_Thule = 3418,
    America_Thunder_Bay = 3432,
    America_Tijuana = 3452,
    America_Toronto = 3468,
    America_Tortola = 3484,
    America_Vancouver = 3500,
    America_Whitehorse = 3518,
    America_Winnipeg = 3537,
    America_Yakutat = 3554,
    America_Yellowknife = 3570,
    Antarctica_Casey = 3590,
    Antarctica_Davis = 3607,
    Antarctica_DumontDUrville = 3624,
    Antarctica_Macquarie = 3650,
    Antarctica_Mawson = 3671,
    Antarctica_McMurdo = 3689,
    Antarctica_Palmer = 3708,
    Antarctica_Rothera = 3726,
    Antarctica_Syowa = 3745,
    Antarctica_Troll = 3762,
    Antarctica_Vostok = 3779,
    Arctic_Longyearbyen = 3797,
    Asia_Aden = 3817,
    Asia_Almaty = 3827,
    Asia_Amman = 3839,
    Asia_Anadyr = 3850,
    Asia_Aqtau = 3862,
    Asia_Aqtobe = 3873,
    Asia_Ashgabat = 3885,
    Asia_Atyrau = 3899,
    Asia_Baghdad = 3911,
    Asia_Bahrain = 3924,
    Asia_Baku = 3937,
    Asia_Bangkok = 3947,
    Asia_Barnaul = 3960,
    Asia_Beirut = 3973,
    Asia_Bishkek = 3985,
    Asia_Brunei = 3998,
    Asia_Chita = 4010,
    Asia_Choibalsan = 4021,
    Asia_Colombo = 4037,
    Asia_Damascus = 4050,
    Asia_Dhaka = 4064,
    Asia_Dili = 4075,
    Asia_Dubai = 4085,
    Asia_Dushanbe = 4096,
    Asia_Famagusta = 4110,
    Asia_Gaza = 4125,
    Asia_Hebron = 4135,
    Asia_Ho_Chi_Minh = 4147,
    Asia_Hong_Kong = 4164,
    Asia_Hovd = 4179,
    Asia_Irkutsk = 4189,
    Asia_Jakarta = 4202,
    Asia_Jayapura = 4215,
    Asia_Jerusalem = 4229,
    Asia_Kabul = 4244,
    Asia_Kamchatka = 4255,
    Asia_Karachi = 4270,
    Asia_Kathmandu = 4283,
    Asia_Khandyga = 4298,
    Asia_Kolkata = 4312,
    Asia_Krasnoyarsk = 4325,
    Asia_Kuala_Lumpur = 4342,
    Asia_Kuching = 4360,
    Asia_Kuwait = 4373,
    Asia_Macau = 4385,
    Asia_Magadan = 4396,
    Asia_Makassar = 4409,
    Asia_Manila = 4423,
    Asia_Muscat = 4435,
    Asia_Nicosia = 4447,
    Asia_Novokuznetsk = 4460,
    Asia_Novosibirsk = 4478,
    Asia_Omsk = 4495,
    Asia_Oral = 4505,
    Asia_Phnom_Penh = 4515,
    Asia_Pontianak = 4531,
    Asia_Pyongyang = 4546,
    Asia_Qatar = 4561,
    Asia_Qostanay = 4572,
    Asia_Qyzylorda = 4586,
    Asia_Riyadh = 4601,
    Asia_Sakhalin = 4613,
    Asia_Samarkand = 4627,
    Asia_Seoul = 4642,
    Asia_Shanghai = 4653,
    Asia_Singapore = 4667,
    Asia_Srednekolymsk = 4682,
    Asia_Taipei = 4701,
    Asia_Tashkent = 4713,
    Asia_Tbilisi = 4727,
    Asia_Tehran = 4740,
    Asia_Thimphu = 4752,
    Asia_Tokyo = 4765,
    Asia_Tomsk = 4776,
    Asia_Ulaanbaatar = 4787,
    Asia_Urumqi = 4804,
    Asia_Ust_Nera = 4816,
    Asia_Vientiane = 4830,
    Asia_Vladivostok = 4845,
    Asia_Yakutsk = 4862,
    Asia_Yangon = 4875,
    Asia_Yekaterinburg = 4887,
    Asia_Yerevan = 4906,
    Atlantic_Azores = 4919,
    Atlantic_Bermuda = 4935,
    Atlantic_Canary = 4952,
    Atlantic_Cape_Verde = 4968,
    Atlantic_Faroe = 4988,
    Atlantic_Madeira = 5003,
    Atlantic_Reykjavik = 5020,
    Atlantic_South_Georgia = 5039,
    Atlantic_St_Helena = 5062,
    Atlantic_Stanley = 5081,
    Australia_Adelaide = 5098,
    Australia_Brisbane = 5117,
    Australia_Broken_Hill = 5136,
    Australia_Currie = 5158,
    Australia_Darwin = 5175,
    Australia_Eucla = 5192,
    Australia_Hobart = 5208,
    Australia_Lindeman = 5225,
    Australia_Lord_Howe = 5244,
    Australia_Melbourne = 5264,
    Australia_Perth = 5284,
    Australia_Sydney = 5300,
    Etc_UTC = 5317,
    Europe_Amsterdam = 5325,
    Europe_Andorra = 5342,
    Europe_Astrakhan = 5357,
    Europe_Athens = 5374,
    Europe_Belgrade = 5388,
    Europe_Berlin = 5404,
    Europe_Bratislava = 5418,
    Europe_Brussels = 5436,
    Europe_Bucharest = 5452,
    Europe_Budapest = 5469,
    Europe_Busingen = 5485,
    Europe_Chisinau = 5501,
    Europe_Copenhagen = 5517,
    Europe_Dublin = 5535,
    Europe_Gibraltar = 5549,
    Europe_Guernsey = 5566,
    Europe_Helsinki = 5582,
    Europe_Isle_of_Man = 5598,
    Europe_Istanbul = 5617,
    Europe_Jersey = 5633,
    Europe_Kaliningrad = 5647,
    Europe_Kiev = 5666,
    Europe_Kirov = 5678,
    Europe_Lisbon = 5691,
    Europe_Ljubljana = 5705,
    Europe_London = 5722,
    Europe_Luxembourg = 5736,
    Europe_Madrid = 5754,
    Europe_Malta = 5768,
    Europe_Mariehamn = 5781,
    Europe_Minsk = 5798,
    Europe_Monaco = 5811,
    Europe_Moscow = 5825,
    Europe_Oslo = 5839,
    Europe_Paris = 5851,
    Europe_Podgorica = 5864,
    Europe_Prague = 5881,
    Europe_Riga = 5895,
    Europe_Rome = 5907,
    Europe_Samara = 5919,
    Europe_San_Marino = 5933,
    Europe_Sarajevo = 5951,
    Europe_Saratov = 5967,
    Europe_Simferopol = 5982,
    Europe_Skopje = 6000,
    Europe_Sofia = 6014,
    Europe_Stockholm = 6027,
    Europe_Tallinn = 6044,
    Europe_Tirane = 6059,
    Europe_Ulyanovsk = 6073,
    Europe_Uzhgorod = 6090,
    Europe_Vaduz = 6106,
    Europe_Vatican = 6119,
    Europe_Vienna = 6134,
    Europe_Vilnius = 6148,
    Europe_Volgograd = 6163,
    Europe_Warsaw = 6180,
    Europe_Zagreb = 6194,
    Europe_Zaporozhye = 6208,
    Europe_Zurich = 6226,
    Indian_Antananarivo = 6240,
    Indian_Chagos = 6260,
    Indian_Christmas = 6274,
    Indian_Cocos = 6291,
    Indian_Comoro = 6304,
    Indian_Kerguelen = 6318,
    Indian_Mahe = 6335,
    Indian_Maldives = 6347,
    Indian_Mauritius = 6363,
    Indian_Mayotte = 6380,
    Indian_Reunion = 6395,
    Pacific_Apia = 6410,
    Pacific_Auckland = 6423,
    Pacific_Bougainville = 6440,
    Pacific_Chatham = 6461,
    Pacific_Chuuk = 6477,
    Pacific_Easter = 6491,
    Pacific_Efate = 6506,
    Pacific_Enderbury = 6520,
    Pacific_Fakaofo = 6538,
    Pacific_Fiji = 6554,
    Pacific_Funafuti = 6567,
    Pacific_Galapagos = 6584,
    Pacific_Gambier = 6602,
    Pacific_Guadalcanal = 6618,
    Pacific_Guam = 6638,
    Pacific_Honolulu = 6651,
    Pacific_Kiritimati = 6668,
    Pacific_Kosrae = 6687,
    Pacific_Kwajalein = 6702,
    Pacific_Majuro = 6720,
    Pacific_Marquesas = 6735,
    Pacific_Midway = 6753,
    Pacific_Nauru = 6768,
    Pacific_Niue = 6782,
    Pacific_Norfolk = 6795,
    Pacific_Noumea = 6811,
    Pacific_Pago_Pago = 6826,
    Pacific_Palau = 6844,
    Pacific_Pitcairn = 6858,
    Pacific_Pohnpei = 6875,
    Pacific_Port_Moresby = 6891,
    Pacific_Rarotonga = 6912,
    Pacific_Saipan = 6930,
    Pacific_Tahiti = 6945,
    Pacific_Tarawa = 6960,
    Pacific_Tongatapu = 6975,
    Pacific_Wake = 6993,
    Pacific_Wallis = 7006,
    Undefined = 7020,
};

#endif
